@@ -1,5 +1,5 @@
 package Text::Hogan;
-$Text::Hogan::VERSION = '0.07';
+$Text::Hogan::VERSION = '0.08';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Text::Hogan - A mustache templating engine statement-for-statement cloned from h
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,20 @@ version 0.07
 
     say $template->render({ name => "Alex" });
 
-See Text::Hogan::Compiler and Text::Hogan::Template for more details.
+See L<Text::Hogan::Compiler|Text::Hogan::Compiler> and L<Text::Hogan::Template|Text::Hogan::Template> for more details.
+
+=head1 SEE ALSO
+
+=head2 Text::Caml
+
+L<Text::Caml|Text::Caml> is a very good mustache-like templating engine, but
+does not support pre-compilation.
+
+=head2 Template::Mustache
+
+L<Template::Mustache|Template::Mustache> is a module written by Pieter van de
+Bruggen and Ricardo Signes. Currently has no POD. Used by
+Dancer::Template::Mustache.
 
 =head1 COPYRIGHT
 
